{% extends "layout_plan.html" %}
{% block title %}Этапы{% endblock %}
{% block content %}
    <h1>Настройки</h1>

    <form method="POST" action="{% url 'preferences_index' %}">
        {% csrf_token %}
        {{ form }}
        <input type="submit" class="btn btn-success" value="Сохранить"/>
    </form>
{% endblock %}
