{% if perms.main.edit_extended_post_attrs %}
    <div class="col-6">
        <div class="form-group">
            <label>{{ form.editor.label }}</label>
            {% if form.editor.errors %}
                <ul class="errors">
                    {% for error in form.section_id.errors %}
                        <li>{{ error }}</li>{% endfor %}
                </ul>
            {% endif %}
            {{ form.editor }}
        </div>
    </div>
{% endif %}
<div class="col-6">
    <div class="form-group">
        <label>{{ form.issues.label }}</label>
        {% if form.issues.errors %}
            <ul class="errors">
                {% for error in form.issues.errors %}
                    <li>{{ error }}</li>{% endfor %}
            </ul>
        {% endif %}
        {{ form.issues }}
        <div class="issues-suggestions">
            {% for issue in issues_suggesions %}
                <div class="suggestion">
                    <a href="#" class="text-success" data-id="{{ issue.id }}">{{ issue }}</a>
                </div>
            {% endfor %}
        </div>
    </div>
</div>

<div class="{% if perms.main.edit_extended_post_attrs %}col-4{% else %}col-6{% endif %}">
    <div class="form-group">
        <label>{{ form.finished_at.label }}</label>
        {% if form.finished_at.errors %}
            <ul class="errors">
                {% for error in form.finished_at.errors %}
                    <li>{{ error }}</li>{% endfor %}
            </ul>
        {% endif %}
        {{ form.finished_at }}
    </div>
</div>

{% if perms.main.edit_extended_post_attrs %}
    {{ form.media }}
    <style type="text/css">
        .django-ace-widget {
            position: initial;
        }
    </style>
    <div class="col-4">
        <div class="form-group">
            <label>{{ form.published_at.label }}</label>
            {% if form.published_at.errors %}
                <ul class="errors">
                    {% for error in form.published_at.errors %}
                        <li>{{ error }}</li>{% endfor %}
                </ul>
            {% endif %}
            {{ form.published_at }}
        </div>
    </div>
    
    <div class="col-4">
        <div class="form-group">
            <label>{{ form.wp_id.label }}</label>
            {% if form.wp_id.errors %}
                <ul class="errors">
                    {% for error in form.title.errors %}
                        <li>{{ error }}</li>{% endfor %}
                </ul>
            {% endif %}
            {{ form.wp_id }}
        </div>
    </div>
    
    <div class="col-12">
        <div class="form-group">
            <label>{{ form.css.label }}</label>
            <p class="small">{{ form.css.help_text }}</p>
            {% if form.css.errors %}
                <ul class="errors">
                    {% for error in form.title.errors %}
                        <li>{{ error }}</li>{% endfor %}
                </ul>
            {% endif %}
            {{ form.css }}
        </div>
    </div>
    
{% endif %}


