{% if post.is_paywalled == True %}
    <div class="bd-callout" role="alert">
        Публикуется с пейволлом
    </div>
{% else %}
    <div class="bd-callout bd-callout-info" role="alert">
        Публикуется без пейволла
    </div>
{% endif%}