<div class="row">
    <div class="col-xl-3 col-lg-3 col-md-3 col-sm-12">
        <div class="form-group">
            {{ user_form.email.label }}
            {% if user_form.email.errors %}
                <ul class="errors">
                    {% for error in form.email.errors %}
                        <li>{{ error }}</li>{% endfor %}
                </ul>
            {% endif %}
            {{ user_form.email }}
        </div>
    </div>
    <div class="col-xl-3 col-lg-3 col-md-3 col-sm-12">
        <div class="form-group">
            {{ profile_form.n_name.label }}
            {% if profile_form.n_name.errors %}
                <ul class="errors">
                    {% for error in form.nickname.errors %}
                        <li>{{ error }}</li>{% endfor %}
                </ul>
            {% endif %}
            {{ profile_form.n_name }}
        </div>
    </div>
    <div class="col-xl-3 col-lg-3 col-md-3 col-sm-12">
        <div class="form-group">
            {{ profile_form.f_name.label }}
            {% if profile_form.f_name.errors %}
                <ul class="errors">
                    {% for error in form.f_name.errors %}
                        <li>{{ error }}</li>{% endfor %}
                </ul>
            {% endif %}
            {{ profile_form.f_name }}
        </div>
    </div>
    <div class="col-xl-3 col-lg-3 col-md-3 col-sm-12">
        <div class="form-group">
            {{ profile_form.l_name.label }}
            {% if profile_form.l_name.errors %}
                <ul class="errors">
                    {% for error in form.l_name.errors %}
                        <li>{{ error }}</li>{% endfor %}
                </ul>
            {% endif %}
            {{ profile_form.l_name }}
        </div>
    </div>
</div>
<div class="row">
    <div class="col-12">
        <div class="form-group">
            {{ profile_form.notes.label }}
            {% if profile_form.notes.errors %}
                <ul class="errors">
                    {% for error in form.notes.errors %}
                        <li>{{ error }}</li>{% endfor %}
                </ul>
            {% endif %}
            {{ profile_form.notes }}
        </div>
    </div>
</div>
