{# HACK: access enum values in templates #}
{% if idea.author_type == AUTHOR_TYPE_CHOICES.1.0 %} {# AUTHOR_TYPE_NEW #}
    <strong>Напишут новые авторы:</strong> {{ idea.authors_new }}
{% elif idea.author_type == AUTHOR_TYPE_CHOICES.2.0 %} {# AUTHOR_TYPE_EXISTING #}
    <strong>Напишут наши авторы:</strong>
    {% for author in idea.authors.all %}
        {% if perms.main.manage_authors %}
            <a href="{% url 'authors_show' author.id %}">{{ author }}</a>{% if forloop.last is False %},
        {% else %}.{% endif %}
        {% else %}
            {{ author }}{% if forloop.last is False %}, {% else %}.{% endif %}
        {% endif %}
    {% endfor %}
{% else %}
    Авторов для этой идеи пока нет.
{% endif %}
