<h1>Идея «{{ idea }}» прошла голосование!</h1>
<p>Идея статьи «{{ idea }}» успешно прошла голосование! По результатам голосования идея заапрувлена.</p>
<p>Теперь из этой идеи можно сделать статью. Зайдите в раздел «Идеи» => «Нет автора», и как только будете готовы начать
    работу над статьей, создайте из идеи статью на странице идеи.</p>
<p><a href="{{ APP_URL }}{% url 'ideas_show' idea.id %}">Посмотреть идею в
    админке</a>.</p>
