# Media elements
image_html = f'''
<figure><img src="%s" alt="%s"><figcaption>%s</figcaption></figure>
'''

# Panels
panel_info = f'''<details><summary>%s</summary><p>%s</p></details>'''
panel_no_title = f'''<details><p>%s</p></details>'''
panel_default = f'''<details><summary>%s</summary><p>%s</p></details>'''
