{% extends "layout_plan.html" %}
{% block title %}{{ issue }}{% endblock %}
{% load filters %}
{% load i18n %}
{% block styles %}
{% endblock %}
{% block content %}

    <h1>{{ issue.full_title }}</h1>

    <div id="stats">
        <h5>
            <strong>{% trans "done" %}:</strong> {{ posts|length|sub:stats.incomplete }} {% trans "of" %} {{ posts|length }}
        </h5>
        <ul>
            <li>{% trans "in_progress" %}: {{ stats.incomplete }}</li>
            <li>{% trans "has_text" %}: {{ stats.has_text }}</li>
            <li>{% trans "no_text" %}: {{ posts|length|sub:stats.has_text }}</li>
        </ul>
    </div>
    <h3>{% trans "articles_in_issue" %} ({{ posts | length }})</h3>

    {% with posts=posts interactive=True %}
        {% include 'magplan/partials/posts_table.html' %}
    {% endwith %}
{% endblock %}
