{% extends "layout_plan.html" %}
{% block title %}{{ issue }}{% endblock %}
{% load filters %}
{% load i18n %}
{% block styles %}
{% endblock %}
{% block content %}

    <h1>Добавить новый выпуск</h1>



    <form method="POST" action="{% url 'issues_create' %}">
        {% csrf_token %}
        {% include 'magplan/issues/_form.html' %}

        <input type="submit" class="btn btn-success" value="Создать выпуск"/>
    </form>
{% endblock %}
